==> Spire.Pdf-9.12.0-py3-none-win_amd64.whl: spire/pdf/PdfListBase.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfListBase(PdfLayoutWidget):
    """
    Represents base class for lists.
    """

    @property
    def Items(self) -> 'PdfListItemCollection':
        """
        Gets items of the list.
        """
        GetDllLibPdf().PdfListBase_get_Items.argtypes = [c_void_p]
        GetDllLibPdf().PdfListBase_get_Items.restype = c_void_p
        intPtr = GetDllLibPdf().PdfListBase_get_Items(self.Ptr)
        ret = None if intPtr == None else PdfListItemCollection(intPtr)
        return ret

    @property
    def Indent(self) -> float:
        """
        Gets or sets tabulation for the list.
        """
        GetDllLibPdf().PdfListBase_get_Indent.argtypes = [c_void_p]
        GetDllLibPdf().PdfListBase_get_Indent.restype = c_float
        ret = GetDllLibPdf().PdfListBase_get_Indent(self.Ptr)
        return ret

    @Indent.setter
    def Indent(self, value: float):
        """
        Sets tabulation for the list.
        """
        GetDllLibPdf().PdfListBase_set_Indent.argtypes = [c_void_p, c_float]
        GetDllLibPdf().PdfListBase_set_Indent(self.Ptr, value)

    @property
    def TextIndent(self) -> float:
        """
        Gets or sets the indent from the marker to the list item text.
        """
        GetDllLibPdf().PdfListBase_get_TextIndent.argtypes = [c_void_p]
        GetDllLibPdf().PdfListBase_get_TextIndent.restype = c_float
        ret = GetDllLibPdf().PdfListBase_get_TextIndent(self.Ptr)
        return ret

    @TextIndent.setter
    def TextIndent(self, value: float):
        """
        Sets the indent from the marker to the list item text.
        """
        GetDllLibPdf().PdfListBase_set_TextIndent.argtypes = [c_void_p, c_float]
        GetDllLibPdf().PdfListBase_set_TextIndent(self.Ptr, value)

    @property
    def Font(self) -> 'PdfFontBase':
        """
        Gets or sets the list font.
        """
        GetDllLibPdf().PdfListBase_get_Font.argtypes = [c_void_p]
        GetDllLibPdf().PdfListBase_get_Font.restype = c_void_p
        intPtr = GetDllLibPdf().PdfListBase_get_Font(self.Ptr)
        ret = None if intPtr == None else PdfFontBase(intPtr)
        return ret

    @Font.setter
    def Font(self, value: 'PdfFontBase'):
        """
        Sets the list font.
        """
        GetDllLibPdf().PdfListBase_set_Font.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfListBase_set_Font(self.Ptr, value.Ptr)

    @property
    def Brush(self) -> 'PdfBrush':
        """
        Gets or sets list brush.
        """
        GetDllLibPdf().PdfListBase_get_Brush.argtypes = [c_void_p]
        GetDllLibPdf().PdfListBase_get_Brush.restype = c_void_p
        intPtr = GetDllLibPdf().PdfListBase_get_Brush(self.Ptr)
        ret = None if intPtr == None else PdfBrush(intPtr)
        return ret

    @Brush.setter
    def Brush(self, value: 'PdfBrush'):
        """
        Sets list brush.
        """
        GetDllLibPdf().PdfListBase_set_Brush.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfListBase_set_Brush(self.Ptr, value.Ptr)

    @property
    def Pen(self) -> 'PdfPen':
        """
        Gets or sets list pen.
        """
        GetDllLibPdf().PdfListBase_get_Pen.argtypes = [c_void_p]
        GetDllLibPdf().PdfListBase_get_Pen.restype = c_void_p
        intPtr = GetDllLibPdf().PdfListBase_get_Pen(self.Ptr)
        ret = None if intPtr == None else PdfPen(intPtr)
        return ret

    @Pen.setter
    def Pen(self, value: 'PdfPen'):
        """
        Sets list pen.
        """
        GetDllLibPdf().PdfListBase_set_Pen.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfListBase_set_Pen(self.Ptr, value.Ptr)

    @property
    def StringFormat(self) -> 'PdfStringFormat':
        """
        Gets or sets the format of the list.
        """
        GetDllLibPdf().PdfListBase_get_StringFormat.argtypes = [c_void_p]
        GetDllLibPdf().PdfListBase_get_StringFormat.restype = c_void_p
        intPtr = GetDllLibPdf().PdfListBase_get_StringFormat(self.Ptr)
        ret = None if intPtr == None else PdfStringFormat(intPtr)
        return ret

    @StringFormat.setter
    def StringFormat(self, value: 'PdfStringFormat'):
        """
        Sets the format of the list.
        """
        GetDllLibPdf().PdfListBase_set_StringFormat.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfListBase_set_StringFormat(self.Ptr, value.Ptr)

    def Draw(self, graphics: 'PdfCanvas', x: float, y: float):
        """
        Draws a list on the Graphics.
        """
        intPtrgraphics: c_void_p = graphics.Ptr
        GetDllLibPdf().PdfListBase_Draw.argtypes = [c_void_p, c_void_p, c_float, c_float]
        GetDllLibPdf().PdfListBase_Draw(self.Ptr, intPtrgraphics, x, y)

==> Spire.Pdf-10.12.1-py3-none-win_amd64.whl: spire/pdf/PdfListBase.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfListBase(PdfLayoutWidget):
    """
    Represents base class for lists.
    """

    @property
    def Items(self) -> 'PdfListItemCollection':
        """
        Gets items of the list.
        """
        GetDllLibPdf().PdfListBase_get_Items.argtypes = [c_void_p]
        GetDllLibPdf().PdfListBase_get_Items.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfListBase_get_Items,self.Ptr)
        ret = None if intPtr == None else PdfListItemCollection(intPtr)
        return ret

    @property
    def Indent(self) -> float:
        """
        Gets or sets tabulation for the list.
        """
        GetDllLibPdf().PdfListBase_get_Indent.argtypes = [c_void_p]
        GetDllLibPdf().PdfListBase_get_Indent.restype = c_float
        ret = CallCFunction(GetDllLibPdf().PdfListBase_get_Indent,self.Ptr)
        return ret

    @Indent.setter
    def Indent(self, value: float):
        """
        Sets tabulation for the list.
        """
        GetDllLibPdf().PdfListBase_set_Indent.argtypes = [c_void_p, c_float]
        CallCFunction(GetDllLibPdf().PdfListBase_set_Indent,self.Ptr, value)

    @property
    def TextIndent(self) -> float:
        """
        Gets or sets the indent from the marker to the list item text.
        """
        GetDllLibPdf().PdfListBase_get_TextIndent.argtypes = [c_void_p]
        GetDllLibPdf().PdfListBase_get_TextIndent.restype = c_float
        ret = CallCFunction(GetDllLibPdf().PdfListBase_get_TextIndent,self.Ptr)
        return ret

    @TextIndent.setter
    def TextIndent(self, value: float):
        """
        Sets the indent from the marker to the list item text.
        """
        GetDllLibPdf().PdfListBase_set_TextIndent.argtypes = [c_void_p, c_float]
        CallCFunction(GetDllLibPdf().PdfListBase_set_TextIndent,self.Ptr, value)

    @property
    def Font(self) -> 'PdfFontBase':
        """
        Gets or sets the list font.
        """
        GetDllLibPdf().PdfListBase_get_Font.argtypes = [c_void_p]
        GetDllLibPdf().PdfListBase_get_Font.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfListBase_get_Font,self.Ptr)
        ret = None if intPtr == None else PdfFontBase(intPtr)
        return ret

    @Font.setter
    def Font(self, value: 'PdfFontBase'):
        """
        Sets the list font.
        """
        GetDllLibPdf().PdfListBase_set_Font.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfListBase_set_Font,self.Ptr, value.Ptr)

    @property
    def Brush(self) -> 'PdfBrush':
        """
        Gets or sets list brush.
        """
        GetDllLibPdf().PdfListBase_get_Brush.argtypes = [c_void_p]
        GetDllLibPdf().PdfListBase_get_Brush.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfListBase_get_Brush,self.Ptr)
        ret = None if intPtr == None else PdfBrush(intPtr)
        return ret

    @Brush.setter
    def Brush(self, value: 'PdfBrush'):
        """
        Sets list brush.
        """
        GetDllLibPdf().PdfListBase_set_Brush.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfListBase_set_Brush,self.Ptr, value.Ptr)

    @property
    def Pen(self) -> 'PdfPen':
        """
        Gets or sets list pen.
        """
        GetDllLibPdf().PdfListBase_get_Pen.argtypes = [c_void_p]
        GetDllLibPdf().PdfListBase_get_Pen.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfListBase_get_Pen,self.Ptr)
        ret = None if intPtr == None else PdfPen(intPtr)
        return ret

    @Pen.setter
    def Pen(self, value: 'PdfPen'):
        """
        Sets list pen.
        """
        GetDllLibPdf().PdfListBase_set_Pen.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfListBase_set_Pen,self.Ptr, value.Ptr)

    @property
    def StringFormat(self) -> 'PdfStringFormat':
        """
        Gets or sets the format of the list.
        """
        GetDllLibPdf().PdfListBase_get_StringFormat.argtypes = [c_void_p]
        GetDllLibPdf().PdfListBase_get_StringFormat.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfListBase_get_StringFormat,self.Ptr)
        ret = None if intPtr == None else PdfStringFormat(intPtr)
        return ret

    @StringFormat.setter
    def StringFormat(self, value: 'PdfStringFormat'):
        """
        Sets the format of the list.
        """
        GetDllLibPdf().PdfListBase_set_StringFormat.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfListBase_set_StringFormat,self.Ptr, value.Ptr)

    def Draw(self, graphics: 'PdfCanvas', x: float, y: float):
        """
        Draws a list on the Graphics.
        """
        intPtrgraphics: c_void_p = graphics.Ptr
        GetDllLibPdf().PdfListBase_Draw.argtypes = [c_void_p, c_void_p, c_float, c_float]
        CallCFunction(GetDllLibPdf().PdfListBase_Draw,self.Ptr, intPtrgraphics, x, y)
